Class: JavaBuildpackUtils::Jre::Release
- Inherits:
-
Object
- Object
- JavaBuildpackUtils::Jre::Release
- Defined in:
- lib/java-buildpack-utils/jre/release.rb
Overview
A class containing the functionality required to describe where the JRE to use is located at runtime
Instance Method Summary collapse
-
#initialize(app_dir) ⇒ Release
constructor
Creates a new instance, passing in the application directory used during release.
-
#run ⇒ String
The execution entry point for release.
Constructor Details
#initialize(app_dir) ⇒ Release
Creates a new instance, passing in the application directory used during release
22 23 |
# File 'lib/java-buildpack-utils/jre/release.rb', line 22 def initialize(app_dir) end |
Instance Method Details
#run ⇒ String
The execution entry point for release. This method is responsible for describing the JAVA_HOME location for the application.
29 30 31 |
# File 'lib/java-buildpack-utils/jre/release.rb', line 29 def run JavaBuildpackUtils::Jre::JAVA_HOME end |