Module: JavaBuildpackUtils::Jre
- Defined in:
- lib/java-buildpack-utils/jre.rb
Overview
A module containing the functionality that allows a user to select which version of the JRE should be used to run their application. The user can set this information by using either a system.properties file in the root of the pushed artifact or using environment variables.
The JRE vendor can be specified by setting the java.runtime.vendor property or the JAVA_RUNTIME_VENDOR environment variable. Legal values for these properties are:
-
oracle
-
openjdk
The JRE version can be specified by setting the java.runtime.version property or the JAVA_RUNTIME_VERSION environment variable. Legal values for these properties are:
-
6 -
7
-
8 -
1.6 -
1.7 -
1.8
Defined Under Namespace
Classes: Compile, Detect, Release, SelectedJre
Constant Summary collapse
- JAVA_HOME =
The relative path to Java within an application
'.java'